@@ -130,9 +130,8 @@ class xtable:
                 for d in data:
                     self.__data.append([d[i] for i in xmap])
         else:
-            if self.__noheader and len(self.__data) > 0:
-                self.__header = self.__data[0]
-                self.__data = self.__data[1:self.__maxrows]
+            if self.__noheader and len(self.__data) > 0 and not self.__header :
+                self.__header =["c"+str(i) for i in range(len(self.__data[0]))]
         self.__num_of_cols = len(self.__header)
         self.__debug = debug
 
@@ -222,25 +221,25 @@ class xtable:
         if changed :
             print("# WARNING : header and data are not well matched!", file=sys.stderr, flush=True)
 
-    def json(self,force_string_typed=False):
+    def json(self):
         self.datafix()
         import json
         tbl = list()
         for r in self.__data:
             row = dict()
             for ix, val in enumerate(r):
-                row[self.__header[ix]] = (str(val) if force_string_typed else val)
+                row[self.__header[ix]] = val
             tbl.append(row)
         return json.dumps(tbl, indent=2)
 
-    def yaml(self,force_string_typed=False):
+    def yaml(self):
         self.datafix()
         import yaml
         tbl = list()
         for r in self.__data:
             row = dict()
             for ix, val in enumerate(r):
-                row[self.__header[ix]] = (str(val) if force_string_typed else val)
+                row[self.__header[ix]] = val
             tbl.append(row)
         return yaml.safe_dump(tbl, default_flow_style=False)
 
@@ -382,13 +381,13 @@ class xtable:
             return (is_a_tty or iscygwin) and (m or supported_platform)
 
         colored = False
-        if supports_color() :
+        if supports_color() or os.environ.get(
+                "force_ansicolor", "").lower() in ["true", "yes", "y", "1"]:
             colored = True
         if self.__force_colored :
             colored = self.__force_colored
-        if os.environ.get("force_ansicolor", "").lower() in ["true", "yes", "y", "1"]:
-            colored = True
-        elif os.environ.get("force_ansicolor", "").lower() in ["false", "no", "n", "0"]:
+        if os.environ.get("force_ansicolor",
+                          "").lower() in ["false", "no", "n", "0"]:
             colored = False
 
         if self.__superwrap:
@@ -446,7 +445,7 @@ class xtable:
                 if m:
                     hc = int(m.group(1))
                 else:
-                    hc = 21
+                    hc = 142
                 if not self.__superwrap:
                     maxcols = columns if self.__cutwrap else 2**20
                     res += '\033[1m' + color(fmtstr.format(*xhdr).strip()[:maxcols],
@@ -637,13 +636,6 @@ def xtable_main():
         default=False,
         help="indicate there's no header",
     )
-    parser.add_argument(
-        "--force_string_typed",
-        dest="forcestring",
-        action="store_true",
-        default=False,
-        help="force string type when dumping JSON/YAML to skip data type limit",
-    )
     parser.add_argument(
         "--tree",
         dest="tree",
@@ -691,9 +683,9 @@ def xtable_main():
             print(t.pivot())
         else:
             if args.format == "json":
-                print(t.json(force_string_typed=args.forcestring), end="")
+                print(t.json(), end="")
             elif args.format == "yaml":
-                print(t.yaml(force_string_typed=args.forcestring), end="")
+                print(t.yaml(), end="")
             elif args.format == "csv":
                 print(t.csv(), end="")
             elif args.format == "html":
@@ -739,7 +731,7 @@ def xtable_main():
     if args.forcecsv:
         done = False
         try:
-            xt = xtable.init_from_csv_fh(INPUT, delimiter=args.sepchar)
+            xt = xtable.init_from_csv_fh(INPUT)
             xt = xtable(
                 header=xt.get_header(),
                 data=xt.get_data(),
